@@ -107,6 +107,14 @@ def ols_namespaces() -> Dict[str, Namespace]:
             description="Molecular Interactions Controlled Vocabulary",
             namespaceEmbeddedInLui=True,
         ),
+        Namespace(
+            id=None,
+            prefix="dron",
+            pattern=r"^DRON:\d+$",
+            name="DRON",
+            description="The drug ontology",
+            namespaceEmbeddedInLui=True,
+        ),
         Namespace(
             id=None,
             prefix="cmo",
@@ -148,6 +156,14 @@ def ols_namespaces() -> Dict[str, Namespace]:
             description="MONDO",
             namespaceEmbeddedInLui=True,
         ),
+        Namespace(
+            id=None,
+            pattern=r"^SIO:\d+$",
+            name="SIO",
+            prefix="sio",
+            description="Semanticscience Integrated Ontology",
+            namespaceEmbeddedInLui=True,
+        ),
         Namespace(
             id=None,
             pattern=r"^STATO:\d+$",
